@@ -15,10 +15,9 @@ else
     echo
     echo Rendering $ASSETS_DIR/$i.png
     $INKSCAPE --export-id=$i \
-              --export-dpi=90 \
               --export-id-only \
-              --export-png=$ASSETS_DIR/$i.png $SRC_FILE >/dev/null \
-     && $OPTIPNG -o7 --quiet $ASSETS_DIR/$i.png
+              --export-png=$ASSETS_DIR/$i.png $SRC_FILE >/dev/null #\
+    # && $OPTIPNG -o7 --quiet $ASSETS_DIR/$i.png 
 fi
 if [ -f $ASSETS_DIR/$i@2.png ]; then
     echo $ASSETS_DIR/$i@2.png exists.
@@ -26,10 +25,10 @@ else
     echo
     echo Rendering $ASSETS_DIR/$i@2.png
     $INKSCAPE --export-id=$i \
-              --export-dpi=180 \
+              --export-dpi=192 \
               --export-id-only \
-              --export-png=$ASSETS_DIR/$i@2.png $SRC_FILE >/dev/null \
-     && $OPTIPNG -o7 --quiet $ASSETS_DIR/$i@2.png
+              --export-png=$ASSETS_DIR/$i@2.png $SRC_FILE >/dev/null #\
+    # && $OPTIPNG -o7 --quiet $ASSETS_DIR/$i@2.png 
 fi
 done
 exit 0
